wallet

package
v0.9.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 10, 2026 License: MIT Imports: 6 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetAddressFromPKAndDescriptor

func GetAddressFromPKAndDescriptor(pk []uint8, descriptor descriptor.Descriptor) ([common.AddressSize]uint8, error)

Types

This section is empty.

Directories

Path Synopsis
Package common provides shared types and utilities for QRL wallet implementations.
Package common provides shared types and utilities for QRL wallet implementations.
Package ml_dsa_87 provides a wallet implementation for ML-DSA-87 signatures on QRL V2.0.
Package ml_dsa_87 provides a wallet implementation for ML-DSA-87 signatures on QRL V2.0.
Package sphincsplus_256s provides a wallet implementation for SPHINCS+-256s signatures on QRL V2.0.
Package sphincsplus_256s provides a wallet implementation for SPHINCS+-256s signatures on QRL V2.0.

Jump to